translate.misc

Package translate :: Package misc |
[hide private]
[frames] | no frames]

# Package misc

source code

Miscellaneous modules for translate - including modules for backward compatibility with pre-2.3 versions of Python

Submodules | [hide private]
translate.misc.autoencode: Supports a hybrid Unicode string that knows which encoding is preferable, and uses this when converting to a string. translate.misc.context translate.misc.contextlib: Utilities for with-statement contexts. translate.misc.dictutils: Implements a case-insensitive (on keys) dictionary and order-sensitive dictionary translate.misc.file_discovery translate.misc.hash: This module contains some temporary glue to make us work with md5 hashes on old and new versions of Python. translate.misc.ini: Access and/or modify INI files translate.misc.lru translate.misc.multistring: Supports a hybrid Unicode string that can also have a list of alternate strings in the strings attribute translate.misc.optrecurse translate.misc.ourdom: module that provides modified DOM functionality for our needs translate.misc.progressbar: progress bar utilities for reporting feedback on progress of application... translate.misc.quote: String processing utilities for extracting strings with various kinds of delimiters translate.misc.selector: selector - WSGI delegation based on URL path and method. translate.misc.sparse: simple parser / string tokenizer rather than returning a list of token types etc, we simple return a list of tokens... translate.misc.stdiotell: A wrapper for sys.stdout etc that provides tell() for current position translate.misc.textwrap: Text wrapping and filling. translate.misc.typecheck translate.misc.typecheck.mixins translate.misc.typecheck.sets translate.misc.typecheck.typeclasses translate.misc.wStringIO: A wrapper for cStringIO that provides more of the functions of StringIO at the speed of cStringIO translate.misc.wsgi: wrapper tht tries to pick the best available wsgi server translate.misc.xml_helpers: Helper functions for working with XML. translate.misc.xmlwrapper: simpler wrapper to the elementtree XML parser translate.misc.zipfileext: extensions to zipfile standard module that will hopefully get included in future...

Imports: autoencode, context, contextlib, dictutils, file_discovery, hash, ini, multistring, optrecurse, ourdom, progressbar, quote, selector, sparse, textwrap, typecheck, wStringIO, wsgi, xml_helpers, zipfileext